/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import javax.xml.soap.SOAPHeaderElement;

import org.apache.axis.types.URI;

/**
 * Java content class for Action element declaration.
 * <p>
 * The following schema fragment specifies the expected content contained within
 * this java content object. (defined at
 * http://schemas.xmlsoap.org/ws/2004/08/addressing line 79)
 *
 * <pre>
 * &lt;element xmlns:wsa=&quot;http://schemas.xmlsoap.org/ws/2004/08/addressing&quot;
 *   name=&quot;Action&quot;
 *   type=&quot;wsa:AttributedURI&quot;/&gt;
 * </pre>
 *
 * @author Davanum Srinivas
 * @author Rodrigo Ruiz
 * @version $Revision: 14 $
 */
public class Action extends AttributedURI {

  /**
   * <code>serialVersionUID</code> attribute.
   */
  private static final long serialVersionUID = 3647655849007062112L;

  /**
   * Creates an instance.
   */
  public Action() {
  }

  /**
   * Creates an instance.
   *
   * @param el Element to extract the action URI from
   * @throws URI.MalformedURIException If the URI is not valid
   */
  public Action(SOAPHeaderElement el) throws URI.MalformedURIException {
    super(el);
  }

  /**
   * Creates an instance.
   *
   * @param uri Action URI
   * @throws URI.MalformedURIException If the URI is not valid
   */
  public Action(String uri) throws URI.MalformedURIException {
    super(uri);
  }

  /**
   * Creates an instance.
   *
   * @param uri Action URI
   */
  public Action(URI uri) {
    super(uri);
  }

  /**
   * {@inheritDoc}
   */
  public String getDefaultElementName() {
    return Constants.ACTION;
  }

}
