/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import javax.xml.soap.SOAPElement;

import org.apache.axis.message.addressing.util.TextExtractor;
import org.apache.axis.types.URI;
import org.w3c.dom.Element;

/**
 * Class Address.
 *
 * @author Davanum Srinivas
 * @author Rodrigo Ruiz
 * @version $Revision: 14 $
 */
public class Address extends AttributedURI {

  /**
   * <code>serialVersionUID</code> attribute.
   */
  private static final long serialVersionUID = 1451978919179135145L;

  /**
   * Gets an Address instance from the specified DOM element.
   *
   * @param element Element to parse
   * @return Address instance
   * @throws MalformedURIException If the parsed URI is not valid
   */
  public static Address fromElement(Element element) throws MalformedURIException {
    String value = TextExtractor.getText(element);
    return new Address(value);
  }

  /**
   * Gets an Address instance from the specified SOAP element.
   *
   * @param element Element to parse
   * @return Address instance
   * @throws MalformedURIException If the parsed URI is not valid
   */
  public static Address fromSOAPElement(SOAPElement element)
    throws MalformedURIException {
    String value = TextExtractor.getText(element);
    return new Address(value);
  }

  /**
   * Constructor Address.
   *
   * @param uri Address URI
   * @throws MalformedURIException If the specified URI is not valid
   */
  public Address(String uri) throws MalformedURIException {
    this(new URI(uri));
  }

  /**
   * Creates an instance.
   *
   * @param uri Address URI
   */
  public Address(URI uri) {
    super(uri);
  }

  /**
   * {@inheritDoc}
   */
  public String getDefaultElementName() {
    return Constants.ADDRESS;
  }
}
