/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import javax.xml.soap.SOAPEnvelope;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPHeaderElement;

/**
 * Common methods to all SOAP Header Element types.
 *
 * @author Rodrigo Ruiz
 * @version $Revision: 14 $
 */
public interface AddressingHeaderItem {

  /**
   * Gets a SOAP Header Element from this instance.
   *
   * @param version  WS-Addressing version to use
   * @param env      SOAP envelope to append to
   * @param actorURI Actor URI
   * @return Header Element
   * @throws SOAPException If an error occurs
   */
  SOAPHeaderElement toSOAPHeaderElement(AddressingVersion version,
    SOAPEnvelope env, String actorURI) throws SOAPException;

  /**
   * Gets a SOAP Header Element from this instance.
   *
   * @param env SOAP envelope to append to
   * @param actorURI Actor URI
   * @return Header Element
   * @throws SOAPException If an error occurs
   */
  SOAPHeaderElement toSOAPHeaderElement(SOAPEnvelope env, String actorURI)
    throws SOAPException;

}
