/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import javax.xml.namespace.QName;

/**
 * Container for several fields that change from one version to another of the
 * WS-Addressing specification.
 * <p>
 * This interface aims to encapsulate all those aspects that vary from
 * one specification to the others.
 *
 * @author Rodrigo Ruiz
 * @version $Revision: 14 $
 */
public interface AddressingVersion {
  /**
   * Gets the URI to use for anonymous target declarations.
   *
   * @return The anonymous target URI
   */
  String getAnonymousRoleURI();

  /**
   * Gets the fault wsa:Action URI that is appropriate for this WSA version.
   *
   * @return The fault Action URI
   */
  String getFaultActionURI();

  /**
   * Gets the namespace associated to this version.
   *
   * @return The namespace for SOAP addressing elements
   */
  String getNamespace();

  /**
   * Returns the response/reply relationship QName that is appropriate for this
   * WSA version..
   *
   * @return The response/reply QName
   */
  QName getResponseRelationshipType();

  /**
   * Gets if the namespace is supported by the W3C specifications.
   *
   * @return <tt>true</tt> if this version is compliant with
   *         the W3C specifications; <tt>false</tt> otherwise
   */
  boolean isW3C();

  /**
   * Gets if this addressing version supports Reference Parameters.
   *
   * @return <tt>true</tt> if reference parameters are supported;
   *         <tt>false</tt> otherwise
   */
  boolean supportsParameters();

  /**
   * Gets if this addressing version supports Reference Properties.
   *
   * @return <tt>true</tt> if reference properties are supported;
   *         <tt>false</tt> otherwise
   */
  boolean supportsProperties();

  /**
   * Gets if this addressing version supports MetaData.
   *
   * @return <tt>true</tt> if MetaData is supported;
   *         <tt>false</tt> otherwise
   */
  boolean supportsMetadata();
}
