/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import javax.xml.soap.Name;

import org.apache.axis.message.PrefixedQName;

/**
 * WS-Addressing constants.
 *
 * @author Davanum Srinivas
 * @version $Revision: 14 $
 */
public interface Constants {

  /**
   * A prefix for the WSA namespace.
   */
  String NS_PREFIX_ADDRESSING = "wsa";

  /**
   * Namespace for 2003/03 revision of WSA schema.
   */
  String NS_URI_ADDRESSING_2003_03 = "http://schemas.xmlsoap.org/ws/2003/03/addressing";

  /**
   * Namespace for 2004/03 revision of WSA schema.
   */
  String NS_URI_ADDRESSING_2004_03 = "http://schemas.xmlsoap.org/ws/2004/03/addressing";

  /**
   * Namespace for 2004/08 revision of WSA schema.
   */
  String NS_URI_ADDRESSING_2004_08 = "http://schemas.xmlsoap.org/ws/2004/08/addressing";

  /**
   * Namespace for 2005/08 revision of WSA schema (CR version too).
   */
  String NS_URI_ADDRESSING_2005_08 = "http://www.w3.org/2005/08/addressing";

  /**
   * Default WSA namespace to use when serializing EPRs or WSA headers.
   */
  String NS_URI_ADDRESSING_DEFAULT = NS_URI_ADDRESSING_2004_08;

  /**
   * Default WSA namespace to use when serializing EPRs or WSA headers.
   *
   * @deprecated Use NS_URI_ADDRESSING_DEFAULT instead.
   */
  @Deprecated
  String NS_URI_ADDRESSING = NS_URI_ADDRESSING_DEFAULT;

  /**
   * Anonymous target URI.
   */
  String URI_ANONYMOUS_W3C_CR = "http://www.w3.org/2005/08/addressing/anonymous";

  /**
   * None URI.
   */
  String URI_NONE_W3C_CR = "http://www.w3.org/2005/08/addressing/none";

  /**
   * Reply URI.
   */
  String URI_REPLY = "http://www.w3.org/2005/08/addressing/reply";

  /**
   * Field ENDPOINT_REFERENCE.
   */
  String ENDPOINT_REFERENCE = "EndpointReference";

  /**
   * Field MESSAGE_ID.
   */
  String MESSAGE_ID = "MessageID";

  /**
   * Field RELATES_TO.
   */
  String RELATES_TO = "RelatesTo";

  /**
   * Field RELATIONSHIP_TYPE.
   */
  String RELATIONSHIP_TYPE = "RelationshipType";

  /**
   * Field ACTION.
   */
  String ACTION = "Action";

  /**
   * The localName of the Address EPR element.
   */
  String ADDRESS = "Address";

  /**
   * The localName of the ReferenceProperties EPR element.
   */
  String REFERENCE_PROPERTIES = "ReferenceProperties";

  /**
   * The localName of the ReferenceParameters EPR element.
   */
  String REFERENCE_PARAMETERS = "ReferenceParameters";

  /**
   * The localName of the ServiceName EPR element.
   */
  String SERVICE_NAME = "ServiceName";

  /**
   * The name of the PortName attribute of the ServiceName EPR element.
   */
  String PORT_NAME = "PortName";

  /**
   * The localName of the PortType EPR element.
   */
  String PORT_TYPE = "PortType";

  /**
   * Field RESPONSE.
   */
  String RESPONSE = "Response";

  /**
   * Field REPLY.
   */
  String REPLY = "Reply";

  /**
   * Field TO.
   */
  String TO = "To";

  /**
   * Field REPLY_TO.
   */
  String REPLY_TO = "ReplyTo";

  /**
   * Field FAULT_TO.
   */
  String FAULT_TO = "FaultTo";

  /**
   * Field FROM.
   */
  String FROM = "From";

  /**
   * Fault-Detail end-point reference field name.
   */
  String FAULT_DETAIL = "FaultDetail";

  /**
   * Field RECIPIENT.
   */
  String RECIPIENT = "Recipient";

  /**
   * Metadata End-point reference field name.
   */
  String METADATA = "Metadata";

  /**
   * Internal property for passing some WSA headers from the generated Stub
   * class to the handlers.
   */
  String ENV_ADDRESSING_SHARED_HEADERS
    = "org.apache.axis.message.addressing.SHARED_HEADERS";

  /**
   * Field ENV_ADDRESSING_REQUEST_HEADERS.
   */
  String ENV_ADDRESSING_REQUEST_HEADERS
    = "org.apache.axis.message.addressing.REQUEST.HEADERS";

  /**
   * Field ENV_ADDRESSING_RESPONSE_HEADERS.
   */
  String ENV_ADDRESSING_RESPONSE_HEADERS
    = "org.apache.axis.message.addressing.RESPONSE.HEADERS";

  /**
   * SOAP message context prop that contains the namespace URI of the WSA
   * version being used by the current request. Value is a String.
   */
  String ENV_ADDRESSING_NAMESPACE_URI = "addressing.namespace.URI";

  /**
   * SOAP message context prop with default value for wsa:From header for
   * outgoing request messages.
   */
  String ENV_ADDRESSING_FROM_URI = "addressing.from.URI";

  /**
   * SOAP message context prop with default value for wsa:ReplyTo header for
   * outgoing request messages.
   */
  String ENV_ADDRESSING_REPLYTO_URI = "addressing.replyTo.URI";

  /**
   * SOAP message context prop with default value for wsa:FaultTo header for
   * outgoing request messages.
   */
  String ENV_ADDRESSING_FAULTTO_URI = "addressing.faultTo.URI";

  /**
   * SOAP message context prop that expects a value of "true" or "false".
   */
  String ENV_ADDRESSING_SET_MUST_UNDERSTAND = "addressing.setMustUnderstand";

  /**
   * SOAP message context prop that expects a value of "true" or "false".
   */
  String ENV_ADDRESSING_SEND_REPLYTO = "addressing.sendReplyTo";

  /**
   * MessageContext property name for setting the response action. Will only
   * work if an action is not already included in the response AddressingHeaders
   * (see AddressingHandler.java).
   */
  String ENV_ADDRESSING_RESP_ACTION = "addressing.responseAction";

  /**
   * MC property for setting the "requiredness" of WS-Addr. If true, the
   * AddressingHandler will fault if there are no WSA headers in received
   * messages.
   */
  String ENV_ADDRESSING_REQUIRED = "addressing.required";

  /**
   * Configuration property.
   */
  String SEND_DEFAULT_FROM = "addressing.sendDefaultFrom";

  /**
   * Configuration property.
   */
  String SEND_DEFAULT_MESSAGEID = "addressing.sendDefaultID";

  /**
   * Configuration property.
   */
  String SEND_DEFAULT_TO = "addressing.sendDefaultTo";

  /**
   * Field QNAME_ACTION.
   */
  String WSDL_ATTRIB_ACTION = "Action";

  /**
   * IsReferenceParameter attribute Name.
   */
  Name ATTR_REFP = new PrefixedQName(NS_URI_ADDRESSING_2005_08, "IsReferenceParameter",
    "wsa");
}
