/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import org.w3c.dom.Element;

/**
 * Represents classes that know how to serialize themselves
 * into a DOM tree.
 *
 * @author Rodrigo Ruiz
 * @version $Revision: 14 $
 */
public interface DOMAppendable {

  /**
   * Appends a DOM representation of this instance to the specified element.
   *
   * @param version     WS-Addressing version to use
   * @param parent      Parent element
   * @param elementName Name of the element to create
   */
  void append(AddressingVersion version, Element parent, String elementName);

  /**
   * Appends a DOM representation of this instance to
   * the specified element.
   *
   * @param parent Parent element
   * @param elementName The name of the element to create
   */
  void append(Element parent, String elementName);

  /**
   * Appends a DOM representation of this instance to
   * the specified element.
   * <p>
   * This method should call {@link #append(Element, String)}
   * with a default value for the elementName parameter. Abstract
   * classes, or those to be always subclassed may optionally
   * throw {@link java.lang.UnsupportedOperationException}
   * instead.
   *
   * @param parent Parent element
   */
  void append(Element parent);
}
