/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import java.io.Serializable;

import javax.xml.namespace.QName;

import org.apache.axis.description.ElementDesc;
import org.apache.axis.description.TypeDesc;
import org.apache.axis.encoding.AnyContentType;
import org.apache.axis.encoding.Deserializer;
import org.apache.axis.encoding.Serializer;
import org.apache.axis.encoding.ser.BeanDeserializer;
import org.apache.axis.encoding.ser.BeanSerializer;
import org.apache.axis.message.MessageElement;
import org.apache.axis.types.URI;

/**
 * Java content class for EndpointReferenceType complex type.
 * <p>
 * The following schema fragment specifies the expected content contained within
 * this java content object. (defined at
 * http://schemas.xmlsoap.org/ws/2004/08/addressing line 46)
 * <p>
 *
 * <pre>
 * &lt;complexType name=&quot;EndpointReferenceType&quot;
 *   xmlns:wsa=&quot;http://schemas.xmlsoap.org/ws/2004/08/addressing&quot;
 *   xmlns:xsd=&quot;http://www.w3.org/2001/XMLSchema&quot;&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base=&quot;xsd:anyType&quot;&gt;
 *       &lt;sequence&gt;
 *         &lt;element name=&quot;Address&quot; type=&quot;wsa:AttributedURI&quot;/&gt;
 *         &lt;element name=&quot;ReferenceProperties&quot;
 *            type=&quot;wsa:ReferencePropertiesType&quot;
 *            minOccurs=&quot;0&quot;/&gt;
 *         &lt;element name=&quot;ReferenceParameters&quot;
 *            type=&quot;wsa:ReferenceParametersType&quot;
 *            minOccurs=&quot;0&quot;/&gt;
 *         &lt;element name=&quot;PortType&quot;
 *            type=&quot;wsa:AttributedQName&quot;
 *            minOccurs=&quot;0&quot;/&gt;
 *         &lt;element name=&quot;ServiceName&quot;
 *            type=&quot;wsa:ServiceNameType&quot;
 *            minOccurs=&quot;0&quot;/&gt;
 *         &lt;any/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 *
 * @author Davanum Srinivas
 * @author Rodrigo Ruiz
 * @version $Revision: 14 $
 */
public class EndpointReferenceType implements AnyContentType, Serializable {
  /**
   * <code>serialVersionUID</code> attribute.
   */
  private static final long serialVersionUID = 16342863069452848L;

  /**
   * Type meta-data.
   */
  private static final TypeDesc TYPE_DESC = new TypeDesc(EndpointReferenceType.class,
    true);

  static {
    String ns = Constants.NS_URI_ADDRESSING_DEFAULT;
    TYPE_DESC.setXmlType(new QName(ns, "EndpointReferenceType"));

    ElementDesc elemField = new ElementDesc();
    elemField.setFieldName("address");
    elemField.setXmlName(new QName(ns, "Address"));
    elemField.setXmlType(new QName(ns, "Address"));
    TYPE_DESC.addFieldDesc(elemField);
    elemField = new ElementDesc();
    elemField.setFieldName("properties");
    elemField.setXmlName(new QName(ns, "ReferenceProperties"));
    elemField.setXmlType(new QName(ns, "ReferencePropertiesType"));
    elemField.setMinOccurs(0);
    TYPE_DESC.addFieldDesc(elemField);
    elemField = new ElementDesc();
    elemField.setFieldName("parameters");
    elemField.setXmlName(new QName(ns, "ReferenceParameters"));
    elemField.setXmlType(new QName(ns, "ReferenceParametersType"));
    elemField.setMinOccurs(0);
    TYPE_DESC.addFieldDesc(elemField);
    elemField = new ElementDesc();
    elemField.setFieldName("portType");
    elemField.setXmlName(new QName(ns, "PortType"));
    elemField.setXmlType(new QName(ns, "PortType"));
    elemField.setMinOccurs(0);
    TYPE_DESC.addFieldDesc(elemField);
    elemField = new ElementDesc();
    elemField.setFieldName("serviceName");
    elemField.setXmlName(new QName(ns, "ServiceName"));
    elemField.setXmlType(new QName(ns, "ServiceNameType"));
    elemField.setMinOccurs(0);
    TYPE_DESC.addFieldDesc(elemField);
    elemField = new ElementDesc();
    elemField.setFieldName("metadata");
    elemField.setXmlName(new QName(ns, "Metadata"));
    elemField.setXmlType(new QName(ns, "MetadataType"));
    elemField.setMinOccurs(0);
    TYPE_DESC.addFieldDesc(elemField);
  }

  /**
   * Gets a custom Deserializer.
   *
   * @param mType not used
   * @param jType Java type
   * @param xType XML type
   * @return A Deserializer instance
   */
  public static Deserializer getDeserializer(String mType, Class<?> jType, QName xType) {
    return new BeanDeserializer(jType, xType, TYPE_DESC);
  }

  /**
   * Gets a custom Serializer.
   *
   * @param mType not used
   * @param jType Java type
   * @param xType XML type
   * @return A Serializer instance
   */
  public static Serializer getSerializer(String mType, Class<?> jType, QName xType) {
    return new BeanSerializer(jType, xType, TYPE_DESC);
  }

  /**
   * Return the type description object.
   *
   * @return Type type description for this class
   */
  public static TypeDesc getTypeDesc() {
    return TYPE_DESC;
  }

  /**
   * Field address.
   */
  private Address address;

  /**
   * Field portType.
   */
  private PortType portType;

  /**
   * Field serviceName.
   */
  private ServiceNameType serviceName;

  /**
   * Field properties.
   */
  private ReferencePropertiesType properties;

  /**
   * Field parameters.
   */
  private ReferenceParametersType parameters;

  /**
   * Meta-data (for W3C version only).
   */
  protected MetaDataType metaData;

  /**
   * Field extensibility elements.
   */
  private MessageElement[] any;

  /**
   * Constructor EndpointReferenceType.
   */
  public EndpointReferenceType() {
  }

  /**
   * Constructor EndpointReferenceType.
   *
   * @param address EndPoint URI
   */
  public EndpointReferenceType(Address address) {
    this.address = address;
  }

  /**
   * Constructor EndpointReferenceType (performs shallow copy).
   *
   * @param endpoint Instance to copy
   */
  public EndpointReferenceType(EndpointReferenceType endpoint) {
    this(endpoint, false);
  }

  /**
   * Constructor EndpointReferenceType.
   *
   * @param endpoint Instance to copy
   * @param deepCopy Whether to perform a deep copy or not
   */
  public EndpointReferenceType(EndpointReferenceType endpoint, boolean deepCopy) {
    if (deepCopy) {
      this.deepCopy(endpoint);
    } else {
      this.shallowCopy(endpoint);
    }
  }

  /**
   * Constructor EndpointReferenceType.
   *
   * @param addr Address URI
   */
  public EndpointReferenceType(URI addr) {
    this.address = new Address(addr);
  }

  /**
   * Performs a copy of the specified elements.
   *
   * @param elems Element array to copy
   * @param deep  Whether to perform a deep or shallow copy
   * @return The copy
   */
  private MessageElement[] copy(MessageElement[] elems, boolean deep) {
    if (elems == null || elems.length == 0) {
      return new MessageElement[0];
    } else if (deep) {
      MessageElement[] copy = new MessageElement[elems.length];
      for (int i = 0; i < elems.length; i++) {
        MessageElement elem = elems[i];
        try {
          copy[i] = new MessageElement(elem.getAsDOM());
        } catch (Exception e) {
          // if failed just copy reference
          copy[i] = elem;
        }
      }
      return copy;
    } else {
      MessageElement[] copy = new MessageElement[elems.length];
      System.arraycopy(elems, 0, copy, 0, elems.length);
      return copy;
    }
  }

  /**
   * Performs a deep copy of the specified instance.
   *
   * @param endpoint Instance to copy
   */
  private void deepCopy(EndpointReferenceType endpoint) {
    AttributedURI addr = endpoint.getAddress();
    if (addr != null) {
      this.setAddress(new Address(addr));
    }
    AttributedQName port = endpoint.getPortType();
    if (port != null) {
      this.setPortType(new PortType(port));
    }
    ServiceNameType sName = endpoint.getServiceName();
    if (sName != null) {
      this.setServiceName(new ServiceNameType(sName));
    }
    ReferencePropertiesType props = endpoint.getProperties();
    if (props != null) {
      this.setProperties(new ReferencePropertiesType(props, true));
    }
    ReferenceParametersType params = endpoint.getParameters();
    if (params != null) {
      this.setParameters(params);
    }
    MetaDataType metadata = endpoint.getMetadata();
    if (metadata != null) {
      this.setMetadata(metadata);
    }

    // handle extensibility
    MessageElement[] elems = endpoint.get_any();
    this.set_any(copy(elems, true));
  }

  /**
   * {@inheritDoc}
   */
  // CHECKSTYLE:OFF (get_any cannot be renamed, as it is part of the Axis API)
  public MessageElement[] get_any() {
  // CHECKSTYLE:ON
    return (this.any == null) ? null : this.any.clone();
  }

  /**
   * Gets the remote address URI.
   *
   * @return the remote address
   */
  public AttributedURI getAddress() {
    return this.address;
  }

  /**
   * Get the meta-data (if any).
   *
   * @return a List of MessageElements, or null
   */
  public MetaDataType getMetadata() {
    return this.metaData;
  }

  /**
   * Method getParameters.
   *
   * @return The reference parameters field
   */
  public ReferenceParametersType getParameters() {
    if (this.parameters == null) {
      this.parameters = new ReferenceParametersType();
    }
    return this.parameters;
  }

  /**
   * Method getPortType.
   *
   * @return The port type name
   */
  public AttributedQName getPortType() {
    return this.portType;
  }

  /**
   * Method getProperties.
   *
   * @return The reference properties field
   */
  public ReferencePropertiesType getProperties() {
    if (this.properties == null) {
      this.properties = new ReferencePropertiesType();
    }
    return this.properties;
  }

  /**
   * Method getServiceName.
   *
   * @return The service name
   */
  public ServiceNameType getServiceName() {
    return this.serviceName;
  }

  /**
   * {@inheritDoc}
   */
  // CHECKSTYLE:OFF (set_any cannot be renamed, as it is part of the Axis API)
  public void set_any(MessageElement[] any) {
  // CHECKSTYLE:ON
    this.any = (any == null) ? null : any.clone();
  }

  /**
   * Method setAddress.
   *
   * @param addr The new address
   */
  public void setAddress(AttributedURI addr) {
    if (addr instanceof Address) {
      this.address = (Address)addr;
    } else {
      this.address = (addr == null) ? null : new Address(addr);
    }
  }

  /**
   * Set the meta-data.
   *
   * @param metaData a List of MessageElements
   */
  public void setMetadata(MetaDataType metaData) {
    this.metaData = metaData;
  }

  /**
   * Method setParameters.
   *
   * @param parameters The reference parameters to set
   */
  public void setParameters(ReferenceParametersType parameters) {
    this.parameters = parameters;
  }

  /**
   * Method setPortType.
   *
   * @param portType The service port type name
   */
  public void setPortType(AttributedQName portType) {
    if (portType instanceof PortType) {
      this.portType = (PortType)portType;
    } else {
      this.portType = (portType == null) ? null : new PortType(portType);
    }
  }

  /**
   * Method setProperties.
   *
   * @param properties The reference properties field
   */
  public void setProperties(ReferencePropertiesType properties) {
    this.properties = properties;
  }

  /**
   * Method setServiceName.
   *
   * @param serviceName The service name
   */
  public void setServiceName(ServiceNameType serviceName) {
    this.serviceName = serviceName;
  }

  /**
   * Performs a shallow copy.
   *
   * @param endpoint Instance to copy
   */
  private void shallowCopy(EndpointReferenceType endpoint) {
    this.setAddress(endpoint.getAddress());
    this.setPortType(endpoint.getPortType());
    this.setServiceName(endpoint.getServiceName());
    ReferencePropertiesType props = endpoint.getProperties();
    if (props != null) {
      this.setProperties(new ReferencePropertiesType(props, false));
    }
    ReferenceParametersType params = endpoint.getParameters();
    if (params != null) {
      this.setParameters(new ReferenceParametersType(params, false));
    }
    MetaDataType metadata = endpoint.getMetadata();
    if (metadata != null) {
      this.setMetadata(new MetaDataType(metadata, false));
    }

    // handle extensibility
    MessageElement[] elems = endpoint.get_any();
    this.set_any(elems);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public String toString() {
    StringBuffer buf = new StringBuffer();
    if (this.address != null) {
      buf.append("Address: ").append(this.address);
      buf.append("\n");
    }
    if (this.portType != null) {
      buf.append("Port Type: ").append(this.portType);
      buf.append("\n");
    }
    if (this.serviceName != null) {
      buf.append("Service Name: ").append(this.serviceName);
      buf.append("\n");
      if (this.serviceName.getPort() != null) {
        buf.append("Port Name: ").append(this.serviceName.getPort());
        buf.append("\n");
      }
    }
    if (this.properties != null) {
      buf.append(this.properties);
      buf.append("\n");
    }
    if (this.parameters != null) {
      buf.append(this.parameters);
      buf.append("\n");
    }
    if (this.metaData != null) {
      buf.append(this.metaData);
      buf.append("\n");
    }

    if (this.any != null) {
      for (int i = 0; i < this.any.length; i++) {
        buf.append("Extensibility Element[").append(i).append("]:\n");
        try {
          buf.append(this.any[i].getAsString());
        } catch (Exception e) {
          buf.append("<error converting: ").append(e.getMessage()).append(">");
        }
        buf.append("\n");
      }
    }
    return buf.toString();
  }
}
