/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import javax.xml.namespace.QName;
import javax.xml.soap.SOAPElement;

import org.apache.axis.description.TypeDesc;
import org.apache.axis.encoding.Deserializer;
import org.apache.axis.encoding.Serializer;
import org.apache.axis.encoding.ser.BeanDeserializer;
import org.apache.axis.encoding.ser.BeanSerializer;
import org.w3c.dom.Element;

/**
 * Java content class for ReferencePropertiesType complex type.
 * <p>
 * The following schema fragment specifies the expected content contained within
 * this java content object. (defined at
 * http://schemas.xmlsoap.org/ws/2004/08/addressing line 62)
 * <p>
 *
 * <pre>
 * &lt;complexType name=&quot;ReferencePropertiesType&quot;&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base=&quot;{http://www.w3.org/2001/XMLSchema}anyType&quot;&gt;
 *       &lt;sequence&gt;
 *         &lt;any/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 *
 * @author Davanum Srinivas
 * @author Rodrigo Ruiz
 * @version $Revision: 14 $
 */
public class MetaDataType extends AnyContentTypeList {

  /**
   * <code>serialVersionUID</code> attribute.
   */
  private static final long serialVersionUID = 6805124334123876433L;

  /**
   * Type meta-data.
   */
  private static final TypeDesc TYPE_DESC = new TypeDesc(ReferencePropertiesType.class,
    true);

  static {
    String ns = Constants.NS_URI_ADDRESSING_DEFAULT;
    TYPE_DESC.setXmlType(new QName(ns, "MetaDataType"));
  }

  /**
   * Parses an XML element node and extracts an instance of this class.
   *
   * @param element Element to parse
   * @return Resulting instance
   */
  public static MetaDataType fromElement(Element element) {
    MetaDataType metaData = new MetaDataType();
    fromElement(metaData, element);
    return metaData;
  }

  /**
   * Parses a SOAP element and extracts an instance of this class.
   *
   * @param element Element to parse
   * @return Resulting instance
   */
  public static MetaDataType fromSOAPElement(SOAPElement element) {
    MetaDataType metaData = new MetaDataType();
    fromSOAPElement(metaData, element);
    return metaData;
  }

  /**
   * Gets a custom Deserializer.
   *
   * @param mType not used
   * @param jType Java type
   * @param xType XML type
   * @return A Deserializer instance
   */
  public static Deserializer getDeserializer(String mType, Class<?> jType, QName xType) {
    return new BeanDeserializer(jType, xType, TYPE_DESC);
  }

  /**
   * Gets a  custom Serializer.
   *
   * @param mType not used
   * @param jType Java type
   * @param xType XML type
   * @return A Serializer instance
   */
  public static Serializer getSerializer(String mType, Class<?> jType, QName xType) {
    return new BeanSerializer(jType, xType, TYPE_DESC);
  }

  /**
   * Return the type description object.
   *
   * @return Type type description for this class
   */
  public static TypeDesc getTypeDesc() {
    return TYPE_DESC;
  }

  /**
   * Creates a new instance.
   */
  public MetaDataType() {
  }

  /**
   * Creates a new instance (performs shallow copy).
   *
   * @param metaData Meta-data to copy
   */
  public MetaDataType(MetaDataType metaData) {
    super(metaData, false);
  }

  /**
   * Creates a new instance, performing a shallow or deep copy of another
   * instance.
   *
   * @param metaData Meta-data to copy
   * @param deepCopy Whether to perform a shallow or deep copy
   */
  public MetaDataType(MetaDataType metaData, boolean deepCopy) {
    super(metaData, deepCopy);
  }

  /**
   * Creates a new instance and adds the specified object as an XML element.
   *
   * @param element Item to add
   */
  public MetaDataType(Object element) {
    super(element);
  }

  /**
   * {@inheritDoc}
   */
  public void append(Element parent) {
    append(parent, Constants.METADATA);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public String toString() {
    return super.toString("Metadata");
  }

}
