/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import javax.xml.namespace.QName;

import org.apache.axis.message.addressing.util.AddressingUtils;
import org.apache.axis.types.URI;
import org.apache.axis.types.URI.MalformedURIException;

/**
 * Java content class for Relationship complex type.
 * <p>
 * The following schema fragment specifies the expected content contained within
 * this java content object. (defined at
 * http://schemas.xmlsoap.org/ws/2004/08/addressing line 84)
 * <p>
 *
 * <pre>
 * &lt;complexType name=&quot;Relationship&quot;&gt;
 *   &lt;simpleContent&gt;
 *     &lt;extension base=&quot;&lt;http://www.w3.org/2001/XMLSchema&gt;anyURI&quot;&gt;
 *       &lt;attribute name=&quot;RelationshipType&quot;
 *                  type=&quot;{http://www.w3.org/2001/XMLSchema}QName&quot; /&gt;
 *     &lt;/extension&gt;
 *   &lt;/simpleContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 *
 * @author Davanum Srinivas
 * @version $Revision: 14 $
 */
public class Relationship {
  /**
   * Field type.
   */
  private URI uri;

  /**
   * Field type.
   */
  private QName type;

  /** Relationship type as per W3C CR version. */
  private String typeIRI;

  /**
   * Constructor Relationship.
   */
  public Relationship() {
  }

  /**
   * Constructor Relationship.
   *
   * @param uri Relationship type
   * @throws URI.MalformedURIException If the URI is not valid
   */
  public Relationship(String uri) throws MalformedURIException {
    this.uri = new URI(uri);
  }

  /**
   * Constructor Relationship.
   *
   * @param uri Relationship URI
   * @param type Relationship type
   * @throws URI.MalformedURIException If any of the URIs is invalid
   */
  public Relationship(String uri, String type) throws MalformedURIException {
    this.typeIRI = type;
    this.uri = new URI(uri);
  }

  /**
   * Constructor Relationship.
   *
   * @param uri Relationship URI
   * @param type Relationship type
   */
  public Relationship(URI uri, QName type) {
    this.uri = uri;
    this.type = (type == null) ? AddressingUtils.getResponseRelationshipType() : type;
  }

  /**
   * Method getType.
   *
   * @return The relationship type
   */
  public QName getType() {
    return this.type;
  }

  /**
   * Gets the type IRI.
   *
   * @return The type IRI
   */
  public String getTypeIRI() {
    return this.typeIRI;
  }

  /**
   * Method getURI.
   *
   * @return The URI
   */
  public URI getURI() {
    return this.uri;
  }

  /**
   * Method set_type.
   *
   * @param type The relationship type
   */
  public void setType(QName type) {
    this.type = type;
  }

  /**
   * Sets the type IRI.
   *
   * @param typeIRI The type IRI
   */
  public void setTypeIRI(String typeIRI) {
    this.typeIRI = typeIRI;
  }

  /**
   * Method setURI.
   *
   * @param uri The URI
   */
  public void setURI(URI uri) {
    this.uri = uri;
  }
}
