/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import java.io.Serializable;

import javax.xml.namespace.QName;

import org.apache.axis.description.ElementDesc;
import org.apache.axis.description.TypeDesc;
import org.apache.axis.encoding.Deserializer;
import org.apache.axis.encoding.Serializer;
import org.apache.axis.encoding.SimpleType;
import org.apache.axis.encoding.ser.SimpleDeserializer;
import org.apache.axis.encoding.ser.SimpleSerializer;
import org.apache.axis.types.NonNegativeInteger;

/**
 * Class ReplyAfterType.
 *
 * @version $Revision: 14 $
 */
public class ReplyAfterType implements Serializable, SimpleType {

  /**
   * <code>serialVersionUID</code> attribute.
   */
  private static final long serialVersionUID = -6723646795809415488L;

  /**
   * Type meta-data.
   */
  private static final TypeDesc TYPE_DESC = new TypeDesc(ReplyAfterType.class, true);

  static {
    String ns = Constants.NS_URI_ADDRESSING_DEFAULT;
    TYPE_DESC.setXmlType(new QName(ns, "ReplyAfterType"));

    ElementDesc elemField = new ElementDesc();

    elemField.setFieldName("value");
    elemField.setXmlName(new QName("", "value"));
    elemField.setXmlType(new QName("http://www.w3.org/2001/XMLSchema",
      "nonNegativeInteger"));
    TYPE_DESC.addFieldDesc(elemField);
  }

  /**
   * Get Custom Deserializer.
   *
   * @param mType Mech type
   * @param jType Java type
   * @param xType XML type
   * @return Deserializer
   */
  public static Deserializer getDeserializer(String mType, Class<?> jType, QName xType) {
    return new SimpleDeserializer(jType, xType, TYPE_DESC);
  }

  /**
   * Get Custom Serializer.
   *
   * @param mType Mech type
   * @param jType Java type
   * @param xType XML type
   * @return Serializer
   */
  public static Serializer getSerializer(String mType, Class<?> jType, QName xType) {
    return new SimpleSerializer(jType, xType, TYPE_DESC);
  }

  /**
   * Return type metadata object.
   *
   * @return Type meta-data
   */
  public static TypeDesc getTypeDesc() {
    return TYPE_DESC;
  }

  /**
   * Field _value.
   */
  private NonNegativeInteger value;

  /**
   * Constructor ReplyAfterType.
   */
  public ReplyAfterType() {
  }

  /**
   * Constructor ReplyAfterType.
   *
   * @param value Value
   */
  public ReplyAfterType(NonNegativeInteger value) {
    this.value = value;
  }

  /**
   * Simple Types must have a String constructor.
   *
   * @param value Value
   */
  public ReplyAfterType(String value) {
    this.value = new NonNegativeInteger(value);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public boolean equals(Object obj) {

    if (this == obj) {
      return true;
    } else if (obj instanceof ReplyAfterType) {
      ReplyAfterType that = (ReplyAfterType) obj;

      NonNegativeInteger v1 = this.getValue();
      NonNegativeInteger v2 = that.getValue();

      return v1 == v2 || v1 != null && v1.equals(v2);
    } else {
      return false;
    }
  }

  /**
   * Gets the value value for this ReplyAfterType.
   *
   * @return value Value
   */
  public NonNegativeInteger getValue() {
    return this.value;
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public int hashCode() {

    int code = 1;

    if (this.getValue() != null) {
      code += this.getValue().hashCode();
    }

    return code;
  }

  /**
   * Sets the value value for this ReplyAfterType.
   *
   * @param value Value
   */
  public void setValue(NonNegativeInteger value) {
    this.value = value;
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public String toString() {
    return this.value == null ? null : this.value.toString();
  }
}
