/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing;

import javax.xml.soap.SOAPEnvelope;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPHeaderElement;

import org.apache.axis.types.URI;
import org.apache.axis.types.URI.MalformedURIException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * Java content class for ReplyTo element declaration.
 * <p>
 * The following schema fragment specifies the expected content contained within
 * this java content object. (defined at
 * http://schemas.xmlsoap.org/ws/2004/08/addressing line 81)
 * <p>
 *
 * <pre>
 * &lt;element
 *   name="ReplyTo"
 *   type="{http://schemas.xmlsoap.org/ws/2004/08/addressing}EndpointReferenceType";/&gt;
 * </pre>
 *
 * @author Davanum Srinivas
 * @version $Revision: 14 $
 */
public class ReplyTo extends EndpointReference {
  /**
   * <code>serialVersionUID</code> attribute.
   */
  private static final long serialVersionUID = -1423217018397296743L;

  /**
   * Constructor ReplyTo.
   *
   * @param address ReplyTo Address
   */
  public ReplyTo(Address address) {
    super(address);
  }

  /**
   * Constructor ReplyTo.
   *
   * @param endpoint ReplyTo Address
   */
  public ReplyTo(EndpointReferenceType endpoint) {
    super(endpoint);
  }

  /**
   * Constructor ReplyTo.
   *
   * @param element Header element
   * @throws MalformedURIException If an error occurs
   */
  public ReplyTo(SOAPHeaderElement element) throws MalformedURIException {
    super(element);
  }

  /**
   * Constructor ReplyTo.
   *
   * @param address ReplyTo Address
   */
  public ReplyTo(URI address) {
    super(address);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public Element toDOM(Document doc) {
    return this.toDOM(doc, Constants.REPLY_TO);
  }

  /**
   * {@inheritDoc}
   */
  public SOAPHeaderElement toSOAPHeaderElement(AddressingVersion version,
    SOAPEnvelope env, String actorURI) throws SOAPException {
    return this.toSOAPHeaderElement(version, env, actorURI, Constants.REPLY_TO);
  }
}
