/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing.handler;

import org.apache.axis.AxisFault;
import org.apache.axis.handlers.BasicHandler;
import org.apache.ws.addressing.uuid.AxisUUIdGenerator;
import org.apache.ws.addressing.uuid.UUIdGeneratorFactory;

import javax.xml.namespace.QName;
import javax.xml.rpc.JAXRPCException;
import javax.xml.rpc.handler.Handler;
import javax.xml.rpc.handler.HandlerInfo;

/**
 * Helper class to which the Axis-specific JAX-RPC handlers in this package
 * can delegate methods defined in the Axis {@link org.apache.axis.Handler}
 * interface. This is done so that the Axis handler base class
 * {@link BasicHandler} can be leveraged.
 *
 * @author Ian P. Springer
 * @version $Revision: 14 $
 */
class GenericAxisHandler extends BasicHandler {

  /**
   * <code>serialVersionUID</code> attribute.
   */
  private static final long serialVersionUID = 8224510670209322980L;

  /**
   * Wrapped handler.
   */
  private transient Handler jaxRpcHandler;

  /**
   * Creates a new instance.
   *
   * @param handler Wrapped handler
   */
  public GenericAxisHandler(Handler handler) {
    jaxRpcHandler = handler;
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public void init() {
    jaxRpcHandler.init(new HandlerInfo(jaxRpcHandler.getClass(), getOptions(),
        new QName[0]));
  }

  /**
   * {@inheritDoc}
   */
  public void invoke(org.apache.axis.MessageContext msgContext) throws AxisFault {
    if (!msgContext.getPastPivot()) {
      jaxRpcHandler.handleRequest(msgContext);
    } else {
      jaxRpcHandler.handleResponse(msgContext);
    }
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public void onFault(org.apache.axis.MessageContext msgContext) {
    jaxRpcHandler.handleFault(msgContext);
  }

  /**
   * Use the UUID generator that comes with Axis.
   *
   * @return a UUID
   */
  String generateUUId() {
    try {
      return UUIdGeneratorFactory.getGenerator().generateUUId();
    } catch (RuntimeException re) {
      throw new JAXRPCException("Failed to generate UUId using Axis UUId generator "
          + AxisUUIdGenerator.class.getName() + ".", re);
    }
  }

}
