/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing.tools.wsdl;

import org.apache.axis.wsdl.gen.Generator;
import org.apache.axis.wsdl.symbolTable.ServiceEntry;
import org.apache.axis.wsdl.symbolTable.SymbolTable;
import org.apache.axis.wsdl.toJava.Emitter;
import org.apache.axis.wsdl.toJava.JavaServiceWriter;

import javax.wsdl.Service;
import java.io.IOException;

/**
 * Service writer.
 *
 * @author Jarek Gawor
 * @version $Revision: 14 $
 */
public class JavaAddressingServiceWriter extends JavaServiceWriter {

  /**
   * Implementation writer.
   */
  protected Generator gridServiceImplWriter = null;

  /**
   * Interface writer.
   */
  protected Generator gridServiceIfaceImplWriter = null;

  /**
   * Constructor.
   *
   * @param emitter     Emitter instance
   * @param service     Service to generate code for
   * @param symbolTable Symbol table
   */
  public JavaAddressingServiceWriter(Emitter emitter, Service service,
      SymbolTable symbolTable) {
    super(emitter, service, symbolTable);

    ServiceEntry sEntry = symbolTable.getServiceEntry(service.getQName());

    if (sEntry.isReferenced()) {
      gridServiceImplWriter = new JavaAddressingServiceImplWriter(emitter, sEntry,
          symbolTable);
      gridServiceIfaceImplWriter = new JavaAddressingServiceIfaceImplWriter(emitter,
          sEntry, symbolTable);
    }
  }

  /**
   * {@inheritDoc}
   */
  public void generate() throws IOException {
    super.generate();

    if (gridServiceImplWriter != null) {
      gridServiceImplWriter.generate();
    }

    if (gridServiceIfaceImplWriter != null) {
      gridServiceIfaceImplWriter.generate();
    }
  }
}
