/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.axis.message.addressing.util;

import javax.xml.namespace.QName;

import org.apache.axis.message.addressing.AddressingVersion;

/**
 * Immutable implementation of the AddressingVersion interface.
 *
 * @author Rodrigo Ruiz
 * @version $Revision: 14 $
 */
class WsaVersion implements AddressingVersion {
  /**
   * Namespace.
   */
  private final String ns;

  /**
   * Anonymous URI.
   */
  private final String anonURI;

  /**
   * Reply/response QName.
   */
  private final QName response;

  /**
   * Is W3C compliant?
   */
  private final boolean w3c;

  /**
   * Supports reference parameters?
   */
  private final boolean params;

  /**
   * Supports reference properties?
   */
  private final boolean props;

  /**
   * Supports meta-data?
   */
  private final boolean mdata;

  /**
   * Creates an instance.
   *
   * @param ns       Namespace
   * @param anonURI  Anonymous URI
   * @param response Response/reply QName
   * @param w3c      Is W3C compliant?
   * @param params   Supports reference parameters?
   * @param props    Supports reference properties?
   * @param mdata    Supports meta-data?
   */
  public WsaVersion(String ns, String anonURI, QName response, boolean w3c,
    boolean params, boolean props, boolean mdata) {
    this.ns = ns;
    this.anonURI = anonURI;
    this.response = response;

    this.w3c = w3c;
    this.params = params;
    this.props = props;
    this.mdata = mdata;
  }

  /**
   * {@inheritDoc}
   */
  public String getAnonymousRoleURI() {
    return anonURI;
  }

  /**
   * {@inheritDoc}
   */
  public String getFaultActionURI() {
    return ns + "/fault";
  }

  /**
   * {@inheritDoc}
   */
  public String getNamespace() {
    return ns;
  }

  /**
   * {@inheritDoc}
   */
  public QName getResponseRelationshipType() {
    return response;
  }

  /**
   * {@inheritDoc}
   */
  public boolean isW3C() {
    return w3c;
  }

  /**
   * {@inheritDoc}
   */
  public boolean supportsMetadata() {
    return mdata;
  }

  /**
   * {@inheritDoc}
   */
  public boolean supportsParameters() {
    return params;
  }

  /**
   * {@inheritDoc}
   */
  public boolean supportsProperties() {
    return props;
  }
}
