/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.ws.addressing.uuid;

/**
 * Provides the ability to generate Universally Unique IDentifiers (UUIDs).
 * Use {@link UUIdGeneratorFactory#getGenerator()} to obtain a singleton
 * instance.
 *
 * @author Ian P. Springer
 * @author Rodrigo Ruiz
 */
public interface UUIdGenerator {

  /**
   * Generate a Universally Unique IDentifier (UUID).
   * <p>
   * IMPORTANT: This method must be thread-safe.
   *
   * @return a Universally Unique IDentifier (UUID)
   */
  String generateUUId();

}
