/*
 *  Copyright (c) 2008 Rodrigo Ruiz
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.ws.addressing.uuid;

import org.apache.commons.discovery.DiscoveryException;
import org.apache.commons.discovery.tools.DiscoverSingleton;

/**
 * A {@link UUIdGenerator} factory.
 *
 * @author Ian P. Springer
 * @author Rodrigo Ruiz
 */
public final class UUIdGeneratorFactory {

  /**
   * Generator instance.
   */
  private static final UUIdGenerator GEN;

  static {
    UUIdGenerator gen;
    try {
      gen = (UUIdGenerator)DiscoverSingleton.find(UUIdGenerator.class);
    } catch (DiscoveryException e) {
      try {
        gen = new JugUUIdGenerator();
      } catch (Throwable t) {
        gen = new AxisUUIdGenerator();
      }
    }
    GEN = gen;
  }

  /**
   * Hidden constructor.
   */
  private UUIdGeneratorFactory() {
  }

  /**
   * Creates a generator, using the default implementation (JUG dependent).
   *
   * @return Generator instance
   */
  public static UUIdGenerator getGenerator() {
    return GEN;
  }
}
